function [ V C eigVeM ddd Cm1 M34 diasIF ] = CrisesGetCoordBaseVP ( diaIstr, diaFopt, entI, entQt, classN, NPar )

% [ V C eigVeM ddd Cm1 M34 ] = CrisesGetCoordBaseVP ('01-Jan-2008', '31-Dec-2008', 1, 319, 0, 6)
%
% Argumentos da funcao:
%    diaIstr : Dia inicial. Na forma: 'dd-Mmm-yyyy' com os meses em ingles
%    diaFopt : Dia final. Ou na forma anterior ou o numero de dias desejados
%       entI : Primeira entidade a utilizar da lista
%              Nao e' usada se se indicarem as classes (sectores).
%      entQt : Numero de entidades a utilizar 
%     classN : Matriz linha com os codigos dos sectores.
%              '0' no caso de se nao desejar especificar os sectores
%       NPar : Numero de parametros a considerar
%              Nao esta' muito utilizavel...
%        fig : Numero da figura em que se representam os dados
%   diaR1str : Dia de inicio de marcacao
%   diaR2str : Dia de fim de marcacao
%
% V       - Volume dos 'NPar' mais revelantes
% C       - Coordenadas para a base dos vectores proprios
% ddd     - Valores proprios por ordem decrescente
% Cm1     - Centro de massa
% M34     - Momentos34
%

load /db/Economia/DataOrg2026/NY_19890420__20090420__319_CtR_Rm000s.mat;

minDim = 1.e-3;   % Valor minimo para validar nova direccao
delta = 0;
diaR1str=diaIstr;

VecDate = Data1.nDate;
[ diaI diaIstr ] = getTestDate (Data1, diaIstr, 1, 1);

%
% Analise da data final. Se 'diaFopt' for uma data e' essa; caso
% contrario e' o numero de dias.
%
[ diaF diaFstr diaQt diaFF ] = getTestDateLast (Data1, diaI, delta, diaFopt);
diaR2str=diaFstr;
diasIF = [datestr(VecDate(diaI)), "_", datestr(VecDate(diaF))];

%
% Intervalo a evidenciar: 'diaR1str' a 'diaR2str'
%
[ iMostra ] = interMostra (Data1, diaI, diaF, diaR1str, diaR2str);

%
% Retira a informacao desejada da estrutura 'Data1' e constroi o titulo
%
[ Dii1 entQt Title1 ] = getDataFromData (Data1, diaI, diaF, entI, entQt,...
    classN, delta, NPar);

fprintf ('De: %s a %s\n', datestr(VecDate(diaI)), datestr(VecDate(diaF)));

Massa1 = ones(1, entQt);
Massa2 = ones(1, 2*entQt);

M = GeoDistance (Dii1, entQt, 1, diaQt);

[X VY dimR] = CoordBaseEnt (M, Massa1, entQt, diaQt, minDim, 0);

[ V C eigVeM ddd Cm1 ] = CoordBaseVP ( X, Massa1, NPar, entQt, dimR, 1);
CCC = C ./ (V^(1/NPar));
[ M34 ] = Momentos34 ( CCC, dimR, V );

